@@ -33,10 +33,11 @@ __PACKAGE__->mk_accessors(
         logger
         debug
         error
+        array_field_values
         )
 );
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 use Rose::Object::MakeMethods::Generic (
     'scalar --get_set_init' => 'searcher',
@@ -293,12 +294,26 @@ sub process_result {
     );
     for my $field (@$fields) {
         my $str = $XMLer->escape( $result->get_property($field) || '' );
-        $str =~ s/\003/ /g;
-        if ( !$apply_hilite or $self->no_hiliting($field) ) {
-            $res{$field} = $str;
+
+        if ( $self->array_field_values ) {
+            if ( !$apply_hilite or $self->no_hiliting($field) ) {
+                $res{$field} = [ split( m/\003/, $str ) ];
+            }
+            else {
+                $res{$field} = [
+                    map { $hiliter->light( $snipper->snip($_) ) }
+                        split( m/\003/, $str )
+                ];
+            }
         }
         else {
-            $res{$field} = $hiliter->light( $snipper->snip($str) );
+            $str =~ s/\003/ /g;
+            if ( !$apply_hilite or $self->no_hiliting($field) ) {
+                $res{$field} = $str;
+            }
+            else {
+                $res{$field} = $hiliter->light( $snipper->snip($str) );
+            }
         }
     }
     return \%res;
@@ -558,6 +573,11 @@ Returns default response format. Defaults to 'XML'.
 
 Get/set the error value for the Engine. 
 
+=head2 array_field_values([boolean])
+
+Return all non-default field values as array refs rather than strings.
+This supports the multi-value \003 separator used by L<SWISH::3>.
+
 =head1 AUTHOR
 
 Peter Karman, C<< <karman at cpan.org> >>
